==> eiffelstudio-18.11.10.2592.tar: F_code/C29/gb1438.c <==
/*
 * Code for class GB_STRING_CONSTANT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb1438.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_STRING_CONSTANT}.make_with_name_and_value */
void F2241_25516 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,arg3);
	RTLR(2,arg1);
	RTLR(3,tr1);
	RTLR(4,arg2);
	RTLIU(5);
	
	RTEAA("make_with_name_and_value", 2240, Current, 0, 3, 31431);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg3;
	RTHOOK(2);
	tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (arg2);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
	RTHOOK(4);
	{
		static EIF_TYPE_INDEX typarr0[] = {1144,75,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1145_10766(RTCW(tr1), ((EIF_INTEGER_32) 4L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {GB_STRING_CONSTANT}.type */
static EIF_REFERENCE F2241_25517_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	

	
	RTEAA("type", 2240, Current, 0, 0, 31432);
	RTOSP (25517);
#define Result RTOSR(25517)
	RTOC_NEW(Result);
	RTHOOK(1);
	Result = RTOSCF(21205,F1926_21205,(Current));
	RTOSE (25517);
	RTHOOK(2);
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F2241_25517 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(25517,F2241_25517_body,(Current));
}

/* {GB_STRING_CONSTANT}.value */
EIF_REFERENCE F2241_25518 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {GB_STRING_CONSTANT}.value_as_string */
EIF_REFERENCE F2241_25519 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTEAA("value_as_string", 2240, Current, 0, 0, 31434);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	Result = (EIF_REFERENCE) eif_builtin_ANY_twin (tr1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_STRING_CONSTANT}.as_multi_column_list_row */
EIF_REFERENCE F2241_25520 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,Result);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("as_multi_column_list_row", 2240, Current, 0, 0, 31435);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1526, 0x00).id, 1526, _OBJSIZ_7_2_0_2_0_0_0_0_);
	F1304_11843(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTOSCF(8319,F616_8319,(Current));
	tr1 = F886_9051(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	F1322_12095(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tr1 = F1470_13703(RTCW(tr1));
	F1170_10956(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTOSCF(25517,F2241_25517,(Current));
	tr1 = F1470_13703(RTCW(tr1));
	F1170_10956(RTCW(Result), tr1);
	RTHOOK(5);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	tr1 = F1470_13703(RTCW(tr1));
	F1170_10956(RTCW(Result), tr1);
	RTHOOK(6);
	F1304_11845(RTCW(Result), Current);
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_STRING_CONSTANT}.can_modify_to_value */
EIF_BOOLEAN F2241_25522 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,loc2);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTEAA("can_modify_to_value", 2240, Current, 2, 1, 31437);
	RTGC;
	RTHOOK(1);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F1145_10797(RTCW(tr1));
	for (;;) {
		RTHOOK(3);
		tb1 = '\01';
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		tb2 = F903_9141(RTCW(tr1));
		if (!tb2) {
			tb1 = (EIF_BOOLEAN) !Result;
		}
		if (tb1) break;
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		loc1 = F1145_10771(RTCW(tr1));
		RTHOOK(5);
		loc2 = F2236_25475(Current, loc1);
		loc2 = *(EIF_REFERENCE *)(RTCW(loc2) + O23232[Dtype(loc2)-2451]);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_3_);
		loc2 = F1134_10640(RTCW(loc2), tr1);
		{
			static EIF_TYPE_INDEX typarr0[] = {1466,0xFFF9,1,1390,1477,1429,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc2 = RTRV(typres0, loc2);
		}
		
		RTHOOK(7);
		tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_POINTER, EIF_REFERENCE, EIF_REFERENCE)) *(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_3_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_3_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(loc2) + _REFACS_1_), arg1);
		*(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_4_2_) = tb2;
		;
		tb2 = tb2;
		RTHOOK(8);
		Result = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_4_2_);
		RTHOOK(9);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		F1145_10799(RTCW(tr1));
	}
	RTHOOK(10);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_STRING_CONSTANT}.modify_value */
void F2241_25523 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,loc2);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTEAA("modify_value", 2240, Current, 2, 1, 31438);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F1145_10797(RTCW(tr1));
	for (;;) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		tb1 = F903_9141(RTCW(tr1));
		if (tb1) break;
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		loc1 = F1145_10771(RTCW(tr1));
		RTHOOK(4);
		loc2 = F2236_25475(Current, loc1);
		loc2 = *(EIF_REFERENCE *)(RTCW(loc2) + O23233[Dtype(loc2)-2451]);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_3_);
		loc2 = F1134_10640(RTCW(loc2), tr1);
		{
			static EIF_TYPE_INDEX typarr0[] = {1464,0xFFF9,1,1390,1477,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc2 = RTRV(typres0, loc2);
		}
		
		RTHOOK(6);
		(FUNCTION_CAST(void, (EIF_POINTER, EIF_REFERENCE, EIF_REFERENCE)) *(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_2_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_2_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(loc2) + _REFACS_1_), arg1);
		;
		RTHOOK(7);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		F1145_10799(RTCW(tr1));
	}
	RTHOOK(8);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg1;
	RTHOOK(10);
	RTLE;
	RTEE;
}

void EIF_Minit1438 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C29/gb1438.c <==
/*
 * Code for class GB_STRING_CONSTANT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb1438.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_STRING_CONSTANT}.make_with_name_and_value */
void F2245_25533 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,arg3);
	RTLR(2,arg1);
	RTLR(3,tr1);
	RTLR(4,arg2);
	RTLIU(5);
	
	RTEAA("make_with_name_and_value", 2244, Current, 0, 3, 31466);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg3;
	RTHOOK(2);
	tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (arg2);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
	RTHOOK(4);
	{
		static EIF_TYPE_INDEX typarr0[] = {1146,77,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1147_10791(RTCW(tr1), ((EIF_INTEGER_32) 4L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {GB_STRING_CONSTANT}.type */
static EIF_REFERENCE F2245_25534_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	

	
	RTEAA("type", 2244, Current, 0, 0, 31467);
	RTOSP (25534);
#define Result RTOSR(25534)
	RTOC_NEW(Result);
	RTHOOK(1);
	Result = RTOSCF(21243,F1928_21243, (Current));
	RTOSE (25534);
	RTHOOK(2);
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F2245_25534 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(25534,F2245_25534_body,(Current));
}

/* {GB_STRING_CONSTANT}.value_as_string */
EIF_REFERENCE F2245_25536 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTEAA("value_as_string", 2244, Current, 0, 0, 31469);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	Result = (EIF_REFERENCE) eif_builtin_ANY_twin (tr1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_STRING_CONSTANT}.as_multi_column_list_row */
EIF_REFERENCE F2245_25537 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("as_multi_column_list_row", 2244, Current, 0, 0, 31470);
	RTGC;
	RTHOOK(1);
	Result = RTLNS(eif_new_type(1528, 0x00).id, 1528, _OBJSIZ_7_2_0_2_0_0_0_0_);
	F1307_11871(RTCW(Result));
	RTHOOK(2);
	tr1 = RTOSCF(8337,F618_8337, (Current));
	tr1 = F888_9071(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	F1325_12123(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tr1 = F1473_13747(RTCW(tr1));
	F1172_10981(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTOSCF(25534,F2245_25534, (Current));
	tr1 = F1473_13747(RTCW(tr1));
	F1172_10981(RTCW(Result), tr1);
	RTHOOK(5);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	tr1 = F1473_13747(RTCW(tr1));
	F1172_10981(RTCW(Result), tr1);
	RTHOOK(6);
	F1307_11873(RTCW(Result), Current);
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_STRING_CONSTANT}.can_modify_to_value */
EIF_BOOLEAN F2245_25539 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,loc2);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTEAA("can_modify_to_value", 2244, Current, 2, 1, 31472);
	RTGC;
	RTHOOK(1);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F1147_10822(RTCW(tr1));
	for (;;) {
		RTHOOK(3);
		tb1 = '\01';
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		tb2 = F905_9161(RTCW(tr1));
		if (!tb2) {
			tb1 = (EIF_BOOLEAN) !Result;
		}
		if (tb1) break;
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		loc1 = F1147_10796(RTCW(tr1));
		RTHOOK(5);
		loc2 = F2243_25523(Current, loc1);
		loc2 = *(EIF_REFERENCE *)(RTCW(loc2) + O23270[Dtype(loc2)-2458]);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_3_);
		loc2 = F1136_10665(RTCW(loc2), tr1);
		{
			static EIF_TYPE_INDEX typarr0[] = {1469,0xFFF9,1,1393,1480,1432,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc2 = RTRV(typres0, loc2);
		}
		
		RTHOOK(7);
		tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_POINTER, EIF_REFERENCE, EIF_REFERENCE)) *(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_3_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_3_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(loc2) + _REFACS_1_), arg1);
		*(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_4_2_) = tb2;
		tb2 = tb2;
		RTHOOK(8);
		Result = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_4_2_);
		RTHOOK(9);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		F1147_10824(RTCW(tr1));
	}
	RTHOOK(10);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_STRING_CONSTANT}.modify_value */
void F2245_25540 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,loc2);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTEAA("modify_value", 2244, Current, 2, 1, 31473);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F1147_10822(RTCW(tr1));
	for (;;) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		tb1 = F905_9161(RTCW(tr1));
		if (tb1) break;
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		loc1 = F1147_10796(RTCW(tr1));
		RTHOOK(4);
		loc2 = F2243_25523(Current, loc1);
		loc2 = *(EIF_REFERENCE *)(RTCW(loc2) + O23271[Dtype(loc2)-2458]);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_3_);
		loc2 = F1136_10665(RTCW(loc2), tr1);
		{
			static EIF_TYPE_INDEX typarr0[] = {1467,0xFFF9,1,1393,1480,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc2 = RTRV(typres0, loc2);
		}
		
		RTHOOK(6);
		(FUNCTION_CAST(void, (EIF_POINTER, EIF_REFERENCE, EIF_REFERENCE)) *(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_2_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_2_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(loc2) + _REFACS_1_), arg1);
		RTHOOK(7);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		F1147_10824(RTCW(tr1));
	}
	RTHOOK(8);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg1;
	RTHOOK(10);
	RTLE;
	RTEE;
}

void EIF_Minit1438 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
